<?php

function amzn_build_features_list_template($Features) {

	$features_list = '';

	if ($Features != null) {

		$features_list = '<ul>';

		foreach ($Features as $feature) {

			// if there is HTML in the feature, like a link, don't include it in the list.
			if (strip_tags($feature) != $feature) continue;

			$features_list .= "<li>".$feature."</li>";

		}

		$features_list .= '</ul>';

	} else {
		return false;
	}

	return $features_list;

}


function amzn_get_template($template_name) {

	$template_group = 'default';
	$template_group = get_option('amzn-template_group');

	$contents = file_get_contents(WPZonBuilder_TEMPLATE_DIR.$template_group."/".$template_name.".html");
	$contents = amzn_template_proc_or_reproc($contents);

	return $contents;
}


function amzn_template_proc_or_reproc($contents) {

	$contents = str_replace("[PluginURL]", WP_PLUGIN_URL."/amzn", $contents);

	// rel='nofollow'
	if (get_option("amzn-relnofollow") == "Yes") {
		$contents = str_replace("[relnofollow]", 'rel="nofollow"', $contents);
	} else {
		$contents = str_replace("[relnofollow]", '', $contents);
	}
	// ---------

	// target='_blank'
	if (get_option("amzn-newwindow") == "Yes") {
		$contents = str_replace("[targetblank]", 'target="_blank"', $contents);
	} else {
		$contents = str_replace("[targetblank]", '', $contents);
	}
	// ---------

	// [hidedupetitle]
	if (get_option("amzn-hidedupetitle") == "Yes") {
		$contents = str_replace("[hidedupetitle]", 'style="display: none;"', $contents);
	} else {
		$contents = str_replace("[hidedupetitle]", '', $contents);
	}

	return $contents;

}


function amzn_css_scripts() {

	$template_group = 'default';
	$template_group = get_option('amzn-template_group');

	$styleurl = WPZonBuilder_TEMPLATE_URL.$template_group."/"."style.css";

	echo "<link rel='stylesheet' href='".$styleurl."' />";

	echo "<script src='".WP_PLUGIN_URL."/amzn/amzniframe.js"."' language='javascript'></script>";

}


function amzn_process_template($pd, $template) {
	
	extract($pd);

	global $post;
	$post_id = $post->ID;
	$postid = $post_id;

	$permalink = get_permalink($postid);

	if ($IsEligibleForSuperSaverShipping == "1") {
		$IsEligibleForSuperSaverShipping_text = WPZonBuilder_SUPERSAVERYES;
	} else {
		$IsEligibleForSuperSaverShipping_text = WPZonBuilder_SUPERSAVERNO;
	}

	$features_list = amzn_build_features_list_template($Features);

	// Links/Click Tracking
	// This is done when processing the template, because then we can use normal URLs everywhere else, and we just change them when they are actually going to be displayed

	$AllCustomerReviewsURL_LINK 		= $AllCustomerReviewsURL;
	$DetailPageURL_LINK 				= $DetailPageURL;
	$TellAFriendURL_LINK 				= $TellAFriendURL;

	if ( get_option('amzn-trackclicks') == 'Yes' ) {

		$url = get_option('siteurl');

		// if post_id's ASIN doesn't match ASIN, look up URL based on ASIN
		$idd = $post_id."/".$ASIN;

		$sepref = get_option("amzn-seoprefix");
		if ($sepref == "") {
			$sepref = "amzn";
		}

		$AllCustomerReviewsURL_LINK = $url.'/'.$sepref.'/'.$idd.'/AllCustomerReviews';
		$DetailPageURL_LINK = $url.'/'.$sepref.'/'.$idd.'/DetailPage';
		$TellAFriendURL_LINK = $url.'/'.$sepref.'/'.$idd.'/TellAFriend';

	} else {

		// if using friendly URLs, tracking ID will be rewritten on redirect. if not, we need to do it now, before it is displayed in template

		$trackingid = get_post_meta($postid, 'amzn_overridetrack', true);
		if ($trackingid != '') {
			$AllCustomerReviewsURL_LINK = amzn_overridetrack($AllCustomerReviewsURL_LINK, $trackingid);
			$DetailPageURL_LINK = amzn_overridetrack($DetailPageURL_LINK, $trackingid);
			$TellAFriendURL_LINK = amzn_overridetrack($TellAFriendURL_LINK, $trackingid);
		}

	}

	// ----------------

	$AllCustomerReviewsURL_LINK = urldecode($AllCustomerReviewsURL_LINK);
	$DetailPageURL_LINK = urldecode($DetailPageURL_LINK);
	$TellAFriendURL_LINK = urldecode($TellAFriendURL_LINK);


	// Language for blanks

	/*
	// Testing the blanks
	$ProductDescription = "";
	$features_list = false;
	$Manufacturer = "";
	$Availability = "";
	$ListPrice = "";
	$LowestNewPrice = "";
	*/

	if ($ProductDescription == "") $ProductDescription = WPZonBuilder_EMPTY_PRODUCT_DESCRIPTION;

	if ($features_list == "") $features_list = WPZonBuilder_EMPTY_FEATURES;

	if ($Manufacturer == "") $Manufacturer = WPZonBuilder_EMPTY_MANUFACTURER;

	if ($Availability == "") $Availability = WPZonBuilder_EMPTY_AVAILABILITY;

	if ($ListPrice == "") $ListPrice = WPZonBuilder_EMPTY_LIST_PRICE;

	if ($LowestNewPrice == "") $LowestNewPrice = WPZonBuilder_EMPTY_LOWEST_NEW_PRICE;


	$content = $template;

	// more info and add to cart buttons

	$addtocartimg = get_option('amzn-addtocartimg');
	$moreinfoimg = get_option('amzn-moreinfoimg');

		// add to cart button URL
		$AssocID = get_post_meta($postid, 'amzn_overridetrack', true);

		if ($AssocID == "") {
			$AssocID = get_option("amzn-aws_assoc_id");
		}

		$countrydomain = amzn_cart_domain();

		$atcurl = "http://www.amazon".$countrydomain."/gp/aws/cart/add.html?AssociateTag=".$AssocID."&ASIN.1=".$ASIN."&Quantity.1=1";
		
		$addtocartcode = '<a [relnofollow] [targetblank] title="[Title]" href="'.$atcurl.'" class="amzn_buynowimage"><img src="[PluginURL]/buttons/'.$addtocartimg.'"></a>';
		// -----------------------
		
		// on-site cart
		if (get_option('amzn-onsitecart') == "Yes") {
			$addtocartcode = '<a [relnofollow] [targetblank] title="[Title]" href="#" onClick="amzn_onsitecartAdd('."'". $postid ."'".');" class="amzn_buynowimage amzn_addtocart_onsite_link"><img src="[PluginURL]/buttons/'.$addtocartimg.'"></a>';
		}
		// ------------------------------
		

	if (get_option('amzn-displaymoreinformation') == "Yes") {
		$content = str_replace("[moreinfo]", '<a [relnofollow] [targetblank] title="[Title]" href="[DetailPageURL]" class="amzn_buynowimage"><img src="[PluginURL]/buttons/'.$moreinfoimg.'"></a>', $content);
	} else {
		$content = str_replace("[moreinfo]", '', $content);
	}

	if (get_option('amzn-displayaddtocart') == "Yes") {
		$content = str_replace("[addtocart]", $addtocartcode, $content);
	} else {
		$content = str_replace("[addtocart]", '', $content);
	}
	

	if (get_option('amzn-displaymoreinformation') == "Yes") {
		$content = str_replace("[moreinfopermalink]", '<a title="[Title]" href="[permalink]" class="amzn_buynowimage"><img src="[PluginURL]/buttons/'.$moreinfoimg.'"></a>', $content);
	} else {
		$content = str_replace("[moreinfopermalink]", '', $content);
	}

	// -----------------------------


	if ($MediumImageURL == "") {
		$MediumImageURL = WPZonBuilder_NOIMAGE_URL;
	}

	if ($SmallImageURL == "") {
		$SmallImageURL = WPZonBuilder_NOIMAGE_URL;
	}

	$content = str_replace("[LargeImage]", $LargeImageURL, $content);
	$content = str_replace("[MediumImage]", $MediumImageURL, $content);
	$content = str_replace("[SmallImage]", $SmallImageURL, $content);
	
	$content = str_replace("[Title]", htmlentities($Title, ENT_COMPAT, 'UTF-8'), $content);

	$content = str_replace("[ListPrice]", $ListPrice, $content);
	$content = str_replace("[SalePrice]", $LowestNewPrice, $content);
	$content = str_replace("[LowestNewPrice]", $LowestNewPrice, $content);
	$content = str_replace("[TotalReviews]", $TotalReviews, $content);
	$content = str_replace("[Manufacturer]", $Manufacturer, $content);

	$content = str_replace("[Availability]", $Availability, $content);
	$content = str_replace("[IsEligibleForSuperSaverShipping]", $IsEligibleForSuperSaverShipping_text, $content);

	$content = str_replace("[ProductDescription]", $ProductDescription, $content);
	$content = str_replace("[Features]", $features_list, $content); // HTML, ul and li

	$StarURL = amzn_get_star_url($AverageRating);
	$content = str_replace("[StarURL]", $StarURL, $content);

	$StarHTML = amzn_get_star_html($AverageRating);
	$content = str_replace("[StarHTML]", $StarHTML, $content);

	$content = str_replace("[permalink]", $permalink, $content);

	$content = str_replace("[DetailPageURL]", $DetailPageURL_LINK, $content);
	$content = str_replace("[AllCustomerReviewsURL]", $AllCustomerReviewsURL_LINK, $content);
	$content = str_replace("[TellAFriendURL]", $TellAFriendURL_LINK, $content);


	// rel='nofollow'
	if (get_option("amzn-relnofollow") == "Yes") {
		$content = str_replace("[relnofollow]", 'rel="nofollow"', $content);
	} else {
		$content = str_replace("[relnofollow]", '', $content);
	}
	// ---------

	// target='_blank'
	if (get_option("amzn-newwindow") == "Yes") {
		$content = str_replace("[targetblank]", 'target="_blank"', $content);
	} else {
		$content = str_replace("[targetblank]", '', $content);
	}
	// ---------

	// [galleryhtml]
	isset($galleryhtml) or $galleryhtml = '';
	$content = str_replace("[galleryhtml]", $galleryhtml, $content);
	// ---------
	
	// iframe reviws
	$iframereviews = '';
	if ( ! empty($IFrameURL) and get_option("amzn-iframereviews") == "Yes") {
		$iframereviews = '<iframe onload="javascript:amzn_resize_frame(this)" width="100%" scrolling="auto" frameborder="0" marginheight="0" src="'.WP_PLUGIN_URL."/amzn/amzniframe.php?url=".base64_encode($IFrameURL).'"></iframe>';
	}
	$content = str_replace("[iframereviews]", $iframereviews, $content);
	// ---------
	
	$content = amzn_template_proc_or_reproc($content);

	return $content;

}

