<?php

class CookieShoppingCart
{

	private $cartkey; // Users can technically see this if they want since Cookies are on client-side, so if you want it to be convoluted then set this to something ugly.
	private $products;
	private $expiration; // Time the shopping cart will last if inactive(in seconds)
	
	
	public function __construct($expiration=7200000)
	{
		$this->cartkey = get_option('amzn-cartkey');
		
		if (isset($_COOKIE[$this->cartkey]))
			$this->products = json_decode(stripslashes($_COOKIE[$this->cartkey]), true);
		else
			$this->products = Array();
		
		$this->expiration = $expiration;
	}
	
	//------------------------------------------------------------------------>
	// Public Interface
	
	public function addToCart($product_id, $quantity=1, $overwrite=FALSE)
	{
		
		if (empty($quantity)) {
			return $this->removeFromCart($product_id);
		}
		
		if ($overwrite === true || !isset($this->products[$product_id])) {
			$this->products[$product_id] = $quantity;
		} else {
			$this->products[$product_id] += $quantity;
		}
		
		$this->saveCartCookie();
	}
	
	public function removeFromCart($product_id)
	{
		if (!isset($this->products[$product_id]))
			return false;
		
		unset($this->products[$product_id]);
		
		$this->saveCartCookie();
		return true;
	}
	
	public function emptyCart()
	{
		$this->products = Array();
		
		$this->saveCartCookie();
	}
	
	public function getCart($keyvalue=false)
	{
		// This returns: Array( "Product ID 1" => [quantity], "Product ID 2" => [quantity] )
		if ($keyvalue)
			return $this->products;
		
		// Otherwise returns: Array( Array("product1", quantity), Array("product2", quantity) )
		$products = Array();
		
		foreach ($this->products as $product_id => $quantity) {
			$products[] = Array($product_id, $quantity);
		}
		
		return $products;
	}
	
	//------------------------------------------------------------------------>
	// Internal functions
	
	private function saveCartCookie()
	{
		setcookie(  $this->cartkey,
					json_encode($this->products),
					time() + $this->expiration,
					'/');
	}

}

?>