<?php 
/*%******************************************************************************************%*/
// EXCEPTIONS

/**
 * Exception: AmazonAAWS_Locale_Exception
 * 
 * @author Pavel Kulbakin <p.kulbakin@gmail.com>
 */
class AmazonAAWS_Locale_Exception extends Exception {}


/*%******************************************************************************************%*/
// MAIN CLASS

/**
 * Defines locale specific API parameters and provides helper function to access them
 * API Version 2011-08-01
 * 
 * @author Pavel Kulbakin <p.kulbakin@gmail.com>
 */
class AmazonAAWS_Locale {

	/**
	 * United States
	 * @var string
	 */
	const US = 'us';
	
	/**
	 * United Kingdom
	 * @var string
	 */
	const UK = 'uk';
	
	/**
	 * Canada
	 * @var string
	 */
	const CANADA = 'ca';
	
	/**
	 * France
	 * @var string
	 */
	const FRANCE = 'fr';
	
	/**
	 * Germany
	 * @var string
	 */
	const GERMANY = 'de';
	
	/**
	 * Japan
	 * @var string
	 */
	const JAPAN = 'jp';
	
	/**
	 * Spain
	 * @var string
	 */
	const SPAIN = 'es';
	
	/**
	 * Italy
	 * @var string
	 */
	const ITALY = 'it';
	
	/**
	 * China
	 * @var string
	 */
	const CHINA = 'cn';
	
	/**
	 * List of supported locales with friendly their names
	 * @var unknown_type
	 */
	protected static $_titles = array(
		'us' => 'United States',
		'uk' => 'United Kingdom',
		'ca' => 'Canada',
		'fr' => 'France',
		'de' => 'Germany',
		'jp' => 'Japan',
		'es' => 'Spain',
		'it' => 'Italy',
		'cn' => 'China',
	);
	
	/**
	 * List of predefined endpoint hostnames
	 * @var array
	 */
	protected static $_endpoints = array(
		'uk' => 'ecs.amazonaws.co.uk',
		'ca' => 'ecs.amazonaws.ca',
		'fr' => 'ecs.amazonaws.fr',
		'de' => 'ecs.amazonaws.de',
		'jp' => 'ecs.amazonaws.jp',
		'es' => 'webservices.amazon.es',
		'it' => 'webservices.amazon.it',
		'cn' => 'webservices.amazon.cn',
		'us' => 'webservices.amazon.com',
	);
	
	/**
	 * List of predefined currency symbols
	 * @var array
	 */
	protected static $_currency_symbols = array(
		'uk' => '&pound;',
		'ca' => 'CDN$ ',
		'fr' => 'EUR ',
		'de' => 'EUR ',
		'jp' => '&yen;',
		'es' => 'EUR ',
		'it' => 'EUR ',
		'cn' => '&yen;',
		'us' => '$',
	);
	/**
	 * Currency number formats presented as array(<decimal precision>, <decimal delimiter>, <thouthand delimiter>)
	 * @var array
	 */
	protected static $_currency_formats = array(
		'uk' => array(2, '.', ','),
		'ca' => array(2, '.', ','),
		'fr' => array(2, ',', '.'),
		'de' => array(2, ',', '.'),
		'jp' => array(2, ',', '.'),
		'es' => array(2, ',', '.'),
		'it' => array(2, ',', '.'),
		'cn' => array(2, '.', ','),
		'us' => array(2, '.', ','),
	);
	/**
	 * List of predefined currency symbols
	 * @var array
	 */
	protected static $_root_domains = array(
		'uk' => 'co.uk',
		'ca' => 'ca',
		'fr' => 'fr',
		'de' => 'de',
		'jp' => 'co.jp',
		'es' => 'es',
		'it' => 'it',
		'cn' => 'cn',
		'us' => 'com',
	);
	/**
	 * List of avarage rating formats (PCRE) to scrape reviews page for them
	 * @var array
	 */
	protected static $_rating_formats = array(
		'uk' => '(\d+(\.\d+)?) out of 5 stars',
		'ca' => '(\d+(\.\d+)?) out of 5 stars',
		'fr' => '(\d+(\.\d+)?) étoiles sur 5',
		'de' => '(\d+(\.\d+)?) von 5 Sternen',
		'jp' => '5つ星のうち (\d+(\.\d+)?)',
		'es' => '(\d+(\.\d+)?) de un máximo de 5 estrellas',
		'it' => '(\d+(\.\d+)?) su 5 stelle',
		'cn' => '平均(\d+(\.\d+)?) 星',
		'us' => '(\d+(\.\d+)?) out of 5 stars',
	);
	/**
	 * List of total number of reviews formats (PCRE) to scrape reviews page for them
	 * @var array
	 */
	protected static $_reviews_formats = array(
		'uk' => '(\d+) customer reviews?',
		'ca' => '(\d+) customer reviews?',
		'fr' => '(\d+) commentaires? client',
		'de' => '(\d+) Kundenrezensionen',
		'jp' => '(\d+)件のカスタマーレビュー',
		'es' => '(\d+) (?:opiniones|opinión) de clientes',
		'it' => '(\d+) recensioni clienti',
		'cn' => '(\d+) 条商品评论',
		'us' => '(\d+) customer reviews?',
	);
	
	/**
	 * List of predefined search options as
	 * array(
	 * 	<SearchIndex> => array(
	 * 		'params' => <Array of Available ItemSearch Parameter Combinations>,
	 * 		'sortValues' => <Array of Sort Values>,
	 * 	),
	 *  ...
	 * )
	 * @var array
	 */
	protected static $_search_indexes = array(
		'us' => array(
			'All' => array(
				'params' => array('Keywords'),
				'sort_values' => array(),
			),
			'Apparel' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'Sort', 'TextStream', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'pricerank', 'inverseprice', '-launch-date', 'sale-flag'),
			),
			'Appliances' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'pmrank', 'price', '-price', 'relevancerank', 'reviewrank',),
			),
			'ArtsAndCrafts' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'Sort', 'Title'),
				'sort_values' => array('pmrank', 'price', '-price', 'relevancerank', 'reviewrank'),
			),
			'Automotive' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'Sort', 'TextStream', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank'),
			),
			'Baby' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'Sort', 'Title'),
				'sort_values' => array('psrank', 'salesrank', 'price', '-price', 'titlerank'),
			),
			'Beauty' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'Sort', 'Title'),
				'sort_values' => array('pmrank', 'salesrank', 'price', '-price', '-launch-date', 'sale-flag'),
			),
			'Blended' => array(
				'params' => array('Keywords'),
				'sort_values' => array(),
			),
			'Books' => array(
				'params' => array('Author', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Power', 'Publisher', 'Sort', 'TextStream', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'reviewrank', 'pricerank', 'inverse-pricerank', 'daterank', 'titlerank', '-titlerank'),
			),
			'Classical' => array(
				'params' => array('Artist', 'Author', 'Availability', 'BrowseNode', 'Composer', 'Conductor', 'Count', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'MusicLabel', 'Orchestra', 'Performer', 'Sort', 'Title'),
				'sort_values' => array('psrank', 'salesrank', 'price', '-price', 'titlerank', '-titlerank', 'orig-rel-date', '-orig-rel-date', 'releasedate', '-releasedate'),
			),
			'DigitalMusic' => array(
				'params' => array('Actor', 'BrowseNode', 'Condition', 'Director', 'ItemPage', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('songtitlerank', 'uploaddaterank'),
			),
			'Grocery' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Keywords', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'pricerank', 'inverseprice', 'launch-date', 'sale-flag'),
			),
			'MP3Downloads' => array(
				'params' => array('Browsenode', 'Keyword', 'Title'),
				'sort_values' => array('price', '-price', '-releasedate', 'relevancerank', 'salesrank'),
			),
			'DVD' => array(
				'params' => array('Actor', 'AudienceRating', 'Availability', 'BrowseNode', 'Count', 'Director', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'Performer', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'titlerank', '-video-release-date', 'releasedate'),
			),
			'Electronics' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort', 'TextStream', 'Title'),
				'sort_values' => array('pmrank', 'salesrank', 'reviewrank', 'price', '-price', 'titlerank'),
			),
			'HealthPersonalCare' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'Sort', 'Title'),
				'sort_values' => array('pmrank', 'salesrank', 'pricerank', 'inverseprice', 'launch-date', 'sale-flag'),
			),
			'HomeGarden' => array( // !!
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank'),
			),
			'Industrial' => array(
				'params' => array('BrowseNode', 'Keywords', 'Manufacturer', 'Title'),
				'sort_values' => array('pmrank', 'salesrank', 'price', '-price', 'titlerank', '-titlerank'),
			),
			'Jewelry' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'Sort', 'TextStream', 'Title'),
				'sort_values' => array('pmrank', 'salesrank', 'pricerank', 'inverseprice', 'launch-date'),
			),
			'KindleStore' => array(
				'params' => array('Author', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Power', 'Publisher', 'Sort', 'TextStream', 'Title'),
				'sort_values' => array('daterank', '-edition-sales-velocity', 'price', '-price', 'relevancerank', 'reviewrank'),
			),
			'Kitchen' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'ItemPage', 'Keywords', 'Sort', 'Title'),
				'sort_values' => array('pmrank', 'salesrank', 'price', '-price', 'titlerank', '-titlerank'),
			),
			'Magazines' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('subslot-salesrank', 'reviewrank', 'price', '-price', 'daterank', 'titlerank', '-titlerank'),
			),
			'Marketplace' => array(
				'params' => array('Availability', 'BrowseNode', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank', '-launch-date'),
			),
			'Merchants' => array(
				'params' => array('Keywords', 'Title', 'BrowseNode', 'Artist', 'Author', 'Actor', 'Director', 'AudienceRating', 'Manufacturer', 'MusicLabel', 'Composer', 'Publisher', 'Brand', 'Conductor', 'Orchestra', 'TextStream'),
				'sort_values' => array('relevancerank', 'salesrank', 'pricerank', 'inverseprice', '-launch-date', 'sale-flag'),
			),
			'Miscellaneous' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'Sort', 'Title'),
				'sort_values' => array('pmrank', 'salesrank', 'price', '-price', 'titlerank', '-titlerank'),
			),
			'MobileApps' => array(
				'params' => array('Availability', 'Author', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('pmrank', 'price', '-price', 'relevancerank', 'reviewrank'),
			),
			'Music' => array(
				'params' => array('Artist', 'Availability', 'BrowseNode', 'Count', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'MusicLabel', 'Performer', 'Sort', 'Title'),
				'sort_values' => array('psrank', 'salesrank', 'price', '-price', 'titlerank', '-titlerank', 'artistrank', 'orig-rel-date', 'release-date', 'releasedate', '-releasedate', 'relevancerank'),
			),
			'MusicalInstruments' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Condition', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'ItemPage', 'Keywords', 'Sort', 'Title'),
				'sort_values' => array('pmrank', 'salesrank', 'price', '-price', '-launch-date', 'sale-flag'),
			),
			'MusicTracks' => array(
				'params' => array('Condition', 'ItemPage', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort'),
				'sort_values' => array('titlerank', '-titlerank'),
			),
			'OfficeProducts' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'Sort', 'Title'),
				'sort_values' => array('pmrank', 'salesrank', 'reviewrank', 'price', '-price', 'titlerank'),
			),
			'OutdoorLiving' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'Sort', 'Title'),
				'sort_values' => array('psrank', 'salesrank', 'price', '-price', 'titlerank', '-titlerank'),
			),
			'PCHardware' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'ItemPage', 'Keywords', 'Sort', 'Title'),
				'sort_values' => array('psrank', 'salesrank', 'price', '-price', 'titlerank'),
			),
			'PetSupplies' => array(
				'params' => array('Author', 'Brand', 'BrowseNode', 'Condition', 'Count', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'Sort', 'Title'),
				'sort_values' => array('+pmrank', 'salesrank', 'price', '-price', 'titlerank', '-titlerank', 'relevancerank', 'reviewrank'),
			),
			'Photo' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'ItemPage', 'Keywords', 'Sort', 'TextStream', 'Title'),
				'sort_values' => array('pmrank', 'salesrank', 'price', '-price', 'titlerank', '-titlerank'),
			),
			'Shoes' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'Sort', 'TextStream', 'Title'),
				'sort_values' => array('-launch-date', 'pmrank', 'price', '-price', 'relevancerank', 'reviewrank'),
			),
			'Software' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'ItemPage', 'Keywords', 'Sort', 'Title'),
				'sort_values' => array('pmrank', 'salesrank', 'price', '-price', 'titlerank'),
			),
			'SportingGoods' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'pricerank', 'inverseprice', 'launch-date', 'sale-flag'),
			),
			'Tools' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'Sort', 'Title'),
				'sort_values' => array('pmrank', 'salesrank', 'price', '-price', 'titlerank', '-titlerank'),
			),
			'Toys' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'Sort', 'TextStream', 'Title'),
				'sort_values' => array('pmrank', 'salesrank', 'price', '-price', 'titlerank', '-age-min'),
			),
			'UnboxVideo' => array(
				'params' => array('Actor', 'BrowseNode', 'Condition', 'Director', 'ItemPage', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MPAARating', 'Publisher', 'Sort', 'TextStream', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'titlerank', '-video-release-date'),
			),
			'VHS' => array(
				'params' => array('Actor', 'AudienceRating', 'Availability', 'BrowseNode', 'Count', 'Director', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'Performer', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'titlerank', '-video-release-date', '-releasedate'),
			),
			'Video' => array(
				'params' => array('Actor', 'AudienceRating', 'Availability', 'BrowseNode', 'Count', 'Director', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'Performer', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'titlerank', '-video-release-date', '-releasedate'),
			),
			'VideoGames' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort', 'TextStream', 'Title'),
				'sort_values' => array('pmrank', 'salesrank', 'price', '-price', 'titlerank'),
			),
			'Watches' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'Sort', 'TextStream', 'Title'),
				'sort_values' => array('price', '-price', 'relevancerank', 'reviewrank', 'salesrank'),
			),
			'Wireless' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'Sort', 'Title'),
				'sort_values' => array('daterank', 'pricerank', 'inverse-pricerank', 'reviewrank', 'salesrank', 'titlerank', '-titlerank'),
			),
			'WirelessAccessories' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MinPercentageOff', 'Sort', 'Title'),
				'sort_values' => array('psrank', 'salesrank', 'titlerank', '-titlerank'),
			),
		),
		
		'uk' => array(
			'All' => array(
				'params' => array('Keywords'),
				'sort_values' => array(),
			),
			'Apparel' => array(
				'params' => array('Author', 'Availability', 'Brand', 'BrowseNode', 'Condition', 'Count', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'Manufacturer', 'Performer', 'Sort', 'Title'),
				'sort_values' => array('-launch-date', 'price', '-price', 'relevancerank', 'reviewrank', 'salesrank'),
			),
			'Automotive' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('price', '-price', 'relevancerank', 'reviewrank', 'salesrank'),
			),
			'Baby' => array(
				'params' => array('Author', 'Availability', 'Brand', 'BrowseNode', 'Condition', 'Count', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'Manufacturer', 'Performer', 'Sort', 'Title'),
				'sort_values' => array('price', '-price', 'relevancerank', 'salesrank'),
			),
			'Beauty' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'Count', 'ItemPage', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Manufacturer', 'Sort', 'Title'),
				'sort_values' => array('price', '-price', 'relevancerank', 'reviewrank', 'salesrank'),
			),
			'Blended' => array(
				'params' => array('Keywords'),
				'sort_values' => array(),
			),
			'Books' => array(
				'params' => array('Author', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Power', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'reviewrank', 'pricerank', 'inverse-pricerank', 'daterank', 'pubdate', 'titlerank', '-titlerank'),
			),
			'Classical' => array(
				'params' => array('Actor', 'Availability', 'BrowseNode', 'Composer', 'Conductor', 'Count', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'MusicLabel', 'Orchestra', 'Performer', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'reviewrank', 'price', '-price', 'inverse-pricerank', 'titlerank', '-titlerank'),
			),
			'DVD' => array(
				'params' => array('Actor', 'AudienceRating', 'Availability', 'BrowseNode', 'Count', 'Director', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'Performer', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'reviewrank', 'price', '-price', 'inverse-pricerank', 'daterank', 'releasedate', 'titlerank', '-titlerank'),
			),
			'Electronics' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'reviewrank', 'price', 'inverse-pricerank', 'daterank', 'titlerank', '-titlerank'),
			),
			'Grocery' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'MaximumPrice', 'MinimumPrice', 'Keywords', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank'),
			),
			'HealthPersonalCare' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'reviewrank', 'price', '-price', 'daterank', 'titlerank', '-titlerank'),
			),
			'HomeGarden' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'reviewrank', 'price', '-price', 'daterank', 'titlerank', '-titlerank'),
			),
			'HomeImprovement' => array( // !!
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('price', '-price', 'reviewrank', 'salesrank'),
			),
			'Jewelry' => array(
				'params' => array('Availability', 'BrowseNode', 'Keywords', 'Sort', 'Title'),
				'sort_values' => array('price', '-price', 'relevancerank', 'reviewrank', 'salesrank'),
			),
			'Kitchen' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'reviewrank', 'price', '-price', 'daterank', 'titlerank', '-titlerank'),
			),
			'Lighting' => array( // !!
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'relevancerank', 'price', '-price', 'reviewrank'),
			),
			'Marketplace' => array(
				'params' => array('Availability', 'BrowseNode', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank', '-launch-date'),
			),
			'MP3Downloads' => array(
				'params' => array('Author', 'Availability', 'BrowseNode', 'Count', 'ItemPage', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'ResponseGroup', 'ReviewSort', 'SearchIndex', 'Sort', 'TagPage', 'TagsPerPage', 'TagSort', 'Title'),
				'sort_values' => array('price', '-price', '-releasedate', 'relevancerank', 'reviewrank', 'salesrank'),
			),
			'Music' => array(
				'params' => array('Artist', 'Availability', 'BrowseNode', 'Count', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'MusicLabel', 'Performer', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'reviewrank', 'releasedate', '-releasedate', 'price', '-price', 'inverse-pricerank', 'titlerank', '-titlerank'),
			),
			'MusicalInstruments' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'MaximumPrice', 'MinimumPrice', 'Keywords', 'Sort', 'Title'),
				'sort_values' => array('reviewrank', 'salesrank', 'price', '-price', 'relevancerank'),
			),
			'MusicTracks' => array(
				'params' => array('Condition', 'ItemPage', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Sort'),
				'sort_values' => array('titlerank', '-titlerank'),
			),
			'OfficeProducts' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('price', '-price', 'relevancerank', 'reviewrank', 'salesrank'),
			),
			'OutdoorLiving' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'reviewrank', 'price', '-price', 'daterank', 'titlerank', '-titlerank'),
			),
			'Outlet' => array(
				'params' => array('Keywords'),
				'sort_values' => array(),
			),
			'PCHardware' => array( // !!
				'params' => array('Brand', 'BrowseNode', 'Condition', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'ItemPage', 'Keywords', 'Sort', 'Title'),
				'sort_values' => array('psrank', 'salesrank', 'price', '-price', 'titlerank'),
			),
			'Shoes' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'Count', 'ItemPage', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Manufacturer', 'Power', 'Sort', 'Title'),
				'sort_values' => array('-launch-date', 'price', '-price', 'relevancerank', 'reviewrank', 'salesrank'),
			),
			'Software' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'reviewrank', 'price', 'inverse-pricerank', 'daterank', 'titlerank', '-titlerank'),
			),
			'SoftwareVideoGames' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'reviewrank', 'price', 'inverse-pricerank', 'daterank', 'titlerank', '-titlerank'),
			),
			'Toys' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', '-mfg-age-min', 'mfg-age-min'),
			),
			'VHS' => array(
				'params' => array('Actor', 'AudienceRating', 'Availability', 'BrowseNode', 'Count', 'Director', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'Performer', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'reviewrank', 'price', '-price', 'inverse-pricerank', 'daterank', 'releasedate', 'titlerank', '-titlerank'),
			),
			'Video' => array(
				'params' => array('Actor', 'AudienceRating', 'Availability', 'BrowseNode', 'Count', 'Director', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'Performer', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'reviewrank', 'price', '-price', 'inverse-pricerank', 'daterank', 'releasedate', 'titlerank', '-titlerank'),
			),
			'VideoGames' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'reviewrank', 'price', 'inverse-pricerank', 'daterank', 'titlerank', '-titlerank'),
			),
			'Watches' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('-launch-date', 'salesrank', 'price', '-price', 'relevancerank', 'titlerank', '-titlerank'),
			),
		),
		
		'jp' => array(
			'All' => array(
				'params' => array('Keywords'),
				'sort_values' => array(),
			),
			'Apparel' => array(
				'params' => array('Author', 'Availability', 'Brand', 'BrowseNode', 'Condition', 'Count', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'Manufacturer', 'Performer', 'Sort', 'Title'),
				'sort_values' => array('price', '-price', 'relevancerank', 'salesrank'),
			),
			'Automotive' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank'),
			),
			'Baby' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('psrank', 'salesrank', 'price', '-price', 'titlerank'),
			),
			'Beauty' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('price', '-price', 'relevancerank', 'reviewrank'),
			),
			'Blended' => array(
				'params' => array('Keywords'),
				'sort_values' => array(),
			),
			'Books' => array(
				'params' => array('Author', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Power', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'pricerank', 'inverse-pricerank', 'daterank', 'titlerank', '-titlerank'),
			),
			'Classical' => array(
				'params' => array('Actor', 'Availability', 'BrowseNode', 'Composer', 'Conductor', 'Count', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'MusicLabel', 'Orchestra', 'Performer', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'pricerank', '-pricerank', 'price', '-price', 'titlerank', '-titlerank', '-orig-rel-date', 'orig-rel-date', 'releasedate', '-releasedate'),
			),
			'DVD' => array(
				'params' => array('Actor', 'AudienceRating', 'Availability', 'BrowseNode', 'Count', 'Director', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'Performer', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'pricerank', '-pricerank', 'price', '-price', 'titlerank', '-titlerank', '-orig-rel-date', 'orig-rel-date', 'releasedate', '-releasedate'),
			),
			'Electronics' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank', '-releasedate', 'releasedate'),
			),
			'ForeignBooks' => array(
				'params' => array('Author', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'pricerank', 'inverse-pricerank', 'daterank', 'titlerank', '-titlerank'),
			),
			'Grocery' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'Count', 'ItemPage', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Manufacturer', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'reviewrank'),
			),
			'HealthPersonalCare' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank'),
			),
			'Hobbies' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank', 'release-date', '-release-date', 'mfg-age-min', '-mfg-age-min'),
			),
			'HomeImprovement' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'relevancerank', 'reviewrank'),
			),
			'Jewelry' => array(
				'params' => array('Availability', 'BrowseNode', 'Keywords', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'relevancerank', 'reviewrank'),
			),
			'Kitchen' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank', '-release-date', 'release-date', 'releasedate', '-releasedate'),
			),
			'Marketplace' => array(
				'params' => array('Availability', 'BrowseNode', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank', '-launch-date'),
			),
			'MP3Downloads' => array(
				'params' => array('Availability', 'BrowseNode', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'titlerank', '-titlerank', 'artistalbumrank', '-artistalbumrank', 'albumrank', '-albumrank', 'runtime', '-runtime', 'price', '-price', 'price-new-bin', '-price-new-bin', 'reviewrank_authority', '-releank', 'releasedate'),
			),
			'Music' => array(
				'params' => array('Artist', 'Availability', 'BrowseNode', 'Count', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'MusicLabel', 'Performer', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'pricerank', '-pricerank', 'price', '-price', 'titlerank', '-titlerank', '-orig-rel-date', 'orig-rel-date', 'releasedate', '-releasedate'),
			),
			'MusicalInstruments' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'MaximumPrice', 'MinimumPrice', 'Keywords', 'Sort', 'Title'),
				'sort_values' => array('reviewrank', 'salesrank', 'price', '-price', 'relevancerank'),
			),
			'MusicTracks' => array(
				'params' => array('Condition', 'ItemPage', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Sort'),
				'sort_values' => array('titlerank', '-titlerank'),
			),
			'OfficeProducts' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'relevancerank', 'reviewrank'),
			),
			'Shoes' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'relevancerank', 'reviewrank'),
			),
			'Software' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank', '-release-date', 'release-date', 'releasedate', '-releasedate'),
			),
			'SportingGoods' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank', 'releasedate', '-releasedate'),
			),
			'Toys' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank', '-release-date', 'release-date', 'releasedate', '-releasedate'),
			),
			'VHS' => array(
				'params' => array('Actor', 'AudienceRating', 'Availability', 'BrowseNode', 'Count', 'Director', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'Performer', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'pricerank', '-pricerank', 'price', '-price', 'titlerank', '-titlerank', '-orig-rel-date', 'orig-rel-date', 'releasedate', '-releasedate'),
			),
			'Video' => array(
				'params' => array('Actor', 'AudienceRating', 'Availability', 'BrowseNode', 'Count', 'Director', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'Performer', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'pricerank', '-pricerank', 'titlerank', '-titlerank', '-orig-rel-date', 'orig-rel-date', 'releasedate', '-releasedate'),
			),
			'VideoGames' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank', '-release-date', 'release-date', 'releasedate', '-releasedate'),
			),
			'Watches' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank'),
			),
		),
		
		'it' => array(
			'All' => array(
				'params' => array('Keywords'),
				'sort_values' => array(),
			),
			'Books' => array(
				'params' => array('Author', 'Availability', 'BrowseNode', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Publisher', 'ReviewSort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', '-pubdate'),
			),
			'DVD' => array(
				'params' => array('Actor', 'AudienceRating', 'Availability', 'BrowseNode', 'Director', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', '-releasedate'),
			),
			'Electronics' => array(
				'params' => array('Availability', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank'),
			),
			'ForeignBooks' => array(
				'params' => array('Author', 'Availability', 'BrowseNode', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Power', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', '-pubdate'),
			),
			'Garden' => array( // !!
				'params' => array('Availability', 'Author', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank'),
			),
			'Kitchen' => array(
				'params' => array('Availability', 'Author', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank'),
			),
			'Music' => array(
				'params' => array('Artist', 'Availability', 'BrowseNode', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'MusicLabel', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', 'reviewrank', '-releasedate'),
			),
			'Shoes' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', '-releasedate'),
			),
			'Software' => array(
				'params' => array('Author', 'Availability', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', '-releasedate'),
			),
			'Toys' => array(
				'params' => array('Availability', 'BrowseNode', 'Keywords', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank'),
			),
			'VideoGames' => array(
				'params' => array('Author', 'Availability', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', '-releasedate'),
			),
			'Watches' => array(
				'params' => array('Availability', 'BrowseNode', 'Keywords', 'Sort'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank'),
			),
		),
		
		'fr' => array(
			'All' => array(
				'params' => array('Keywords'),
				'sort_values' => array(),
			),
			'Apparel' => array(
				'params' => array('Availability', 'Author', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('reviewrank', 'salesrank', 'price', '-price', 'relevancerank'),
			),
			'Baby' => array(
				'params' => array('Availability', 'Author', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('price', '-price', 'relevancerank', 'salesrank'),
			),
			'Beauty' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('price', '-price', 'relevancerank', 'reviewrank', 'salesrank'),
			),
			'Blended' => array(
				'params' => array('Keywords'),
				'sort_values' => array(),
			),
			'Books' => array(
				'params' => array('Author', 'BrowseNode', 'Condition', 'Count', 'ItemPage', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Power', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'pricerank', 'inverse-pricerank', '-daterank', 'titlerank', '-titlerank'),
			),
			'Classical' => array(
				'params' => array('Actor', 'Availability', 'BrowseNode', 'Composer', 'Conductor', 'Count', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'MusicLabel', 'Orchestra', 'Performer', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'pricerank', 'price', 'inverse-pricerank', '-price', 'titlerank', '-titlerank'),
			),
			'DVD' => array(
				'params' => array('Actor', 'AudienceRating', 'Availability', 'BrowseNode', 'Count', 'Director', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'Performer', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('amzrank', 'availability', 'salesrank', 'titlerank', '-titlerank'),
			),
			'Electronics' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank'),
			),
			'ForeignBooks' => array(
				'params' => array('Author', 'BrowseNode', 'Condition', 'Count', 'ItemPage', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Power', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'pricerank', 'inverse-pricerank', '-daterank', 'titlerank', '-titlerank'),
			),
			'HealthPersonalCare' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'KeyWords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('price', '-price', 'relevancerank', 'reviewrank', 'salesrank'),
			),
			'Jewelry' => array(
				'params' => array('Availability', 'BrowseNode', 'Keywords', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'relevancerank', 'reviewrank'),
			),
			'Kitchen' => array(
				'params' => array('Author', 'Availability', 'Brand', 'BrowseNode', 'Condition', 'Count', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'Manufacturer', 'Performer', 'Sort', 'Title'),
				'sort_values' => array('price', '-price', 'relevancerank', 'salesrank'),
			),
			'Lighting' => array( // !!
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'relevancerank', 'price', '-price', 'reviewrank'),
			),
			'MP3Downloads' => array(
				'params' => array('Availability', 'BrowseNode', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('albumrank', '-albumrank', 'artistalbumrank', '-artistalbumrank', 'price', '-price', 'runtime', '-runtime', '-releasedate', 'relevancerank', 'reviewrank', 'salesrank', 'titlerank', '-titlerank'),
			),
			'Music' => array(
				'params' => array('Artist', 'Availability', 'BrowseNode', 'Count', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'MusicLabel', 'Performer', 'Sort', 'Title'),
				'sort_values' => array('releasedate', '-releasedate', 'salesrank', 'pricerank', 'inverse-pricerank', 'price', '-price', 'titlerank', '-titlerank'),
			),
			'MusicalInstruments' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'MaximumPrice', 'MinimumPrice', 'Keywords', 'Sort', 'Title'),
				'sort_values' => array('reviewrank', 'salesrank', 'price', '-price', 'relevancerank'),
			),
			'MusicTracks' => array(
				'params' => array('BrowseNode', 'Condition', 'Count', 'ItemPage', 'Keywords', 'MinimumPrice', 'Sort'),
				'sort_values' => array('titlerank', '-titlerank'),
			),
			'OfficeProducts' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('price', '-price', 'relevancerank', 'reviewrank', 'salesrank'),
			),
			'Outlet' => array(
				'params' => array('Keywords'),
				'sort_values' => array(),
			),
			'Shoes' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('price', '-price', 'relevancerank', 'salesrank', 'reviewrank'),
			),
			'PCHardware' => array( // !!
				'params' => array('Brand', 'BrowseNode', 'Condition', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'ItemPage', 'Keywords', 'Sort', 'Title'),
				'sort_values' => array('psrank', 'salesrank', 'price', '-price', 'titlerank'),
			),
			'Software' => array(
				'params' => array('BrowseNode', 'Condition', 'Count', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-pricerank', 'titlerank', '-titlerank'),
			),
			'SoftwareVideoGames' => array(
				'params' => array('Author', 'BrowseNode', 'Condition', 'Count', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-pricerank', 'titlerank', '-titlerank', '-date'),
			),
			'SportingGoods' => array( // !!
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank', 'releasedate', '-releasedate'),
			),
			'VHS' => array(
				'params' => array('Actor', 'AudienceRating', 'Availability', 'BrowseNode', 'Count', 'Director', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'Performer', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('amzrank', 'availability', 'salesrank', 'titlerank', '-titlerank'),
			),
			'Video' => array(
				'params' => array('Actor', 'AudienceRating', 'Availability', 'BrowseNode', 'Director', 'ItemPage', 'Keywords', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank'),
			),
			'VideoGames' => array(
				'params' => array('Author', 'Brand', 'BrowseNode', 'Condition', 'Count', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'date', 'titlerank', '-titlerank'),
			),
			'Watches' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('price', '-price', 'salesrank', 'relevancerank', 'reviewrank'),
			),
		),
		
		'es' => array(
			'All' => array(
				'params' => array('Keywords'),
				'sort_values' => array(),
			),
			'Books' => array(
				'params' => array('Availability', 'Author', 'BrowseNode', 'DeliveryMethod', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Power', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', 'reviewrank_authority', '-pubdate', '-publicationdate'),
			),
			'DVD' => array(
				'params' => array('Actor', 'AudienceRating', 'Availability', 'BrowseNode', 'DeliveryMethod', 'Director', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', 'reviewrank_authority', '-releasedate'),
			),
			'Electronics' => array(
				'params' => array('Availability', 'BrowseNode', 'DeliveryMethod', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', 'reviewrank_authority'),
			),
			'ForeignBooks' => array(
				'params' => array('Availability', 'Author', 'BrowseNode', 'DeliveryMethod', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Power', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', 'reviewrank_authority', '-pubdate', '-publicationdate'),
			),
			'Kitchen' => array(
				'params' => array('Availability', 'Author', 'Brand', 'BrowseNode', 'DeliveryMethod', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Keywords', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', 'reviewrank_authority'),
			),
			'Music' => array(
				'params' => array('Artist', 'Availability', 'BrowseNode', 'DeliveryMethod', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MusicLabel', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', 'reviewrank_authority', '-releasedate'),
			),
			'Software' => array(
				'params' => array('Availability', 'Author', 'Brand', 'BrowseNode', 'DeliveryMethod', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Keywords', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', 'reviewrank_authority', '-releasedate'),
			),
			'Toys' => array(
				'params' => array('Availability', 'BrowseNode', 'DeliveryMethod', 'Keywords', 'MerchantId', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', 'reviewrank_authority'),
			),
			'VideoGames' => array(
				'params' => array('Availability', 'Author', 'Brand', 'BrowseNode', 'DeliveryMethod', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', 'reviewrank_authority', '-releasedate'),
			),
			'Watches' => array(
				'params' => array('Availability', 'BrowseNode', 'DeliveryMethod', 'Keywords', 'MerchantId', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', 'reviewrank_authority'),
			),
		),
		
		'de' => array(
			'All' => array(
				'params' => array('Keywords'),
				'sort_values' => array(),
			),
			'Apparel' => array(
				'params' => array('Author', 'Availability', 'Brand', 'BrowseNode', 'Condition', 'Count', 'Format', 'ISPUPostalCode', 'ItemPage', 'Keywords', 'Magazines', 'Manufacturer', 'MerchantId', 'Performer', 'ReviewRank', 'Sort', 'Title'),
				'sort_values' => array('price', '-price', 'relevancerank', 'reviewrank', 'salesrank'),
			),
			'Automotive' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort', 'TextStream', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'reviewrank'),
			),
			'Baby' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('price', '-price', 'relevancerank', 'salesrank'),
			),
			'Blended' => array(
				'params' => array('Keywords'),
				'sort_values' => array(),
			),
			'Beauty' => array(
				'params' => array('Brand', 'BrowseNode', 'Condition', 'Count', 'ItemPage', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Manufacturer', 'MerchantId', 'Sort', 'Title'),
				'sort_values' => array('price', '-price', 'relevancerank', 'reviewrank', 'salesrank'),
			),
			'Books' => array(
				'params' => array('Author', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Power', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'reviewrank', 'pricerank', 'inverse-pricerank', 'titlerank', '-titlerank'),
			),
			'Classical' => array(
				'params' => array('Artist', 'Availability', 'BrowseNode', 'Composer', 'Conductor', 'Count', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'MusicLabel', 'Orchestra', 'Performer', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'pubdate', '-pubdate', 'publication_date', '-publication_date', 'titlerank', '-titlerank'),
			),
			'DVD' => array(
				'params' => array('Actor', 'Availability', 'BrowseNode', 'Composer', 'Conductor', 'Count', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'MusicLabel', 'Orchestra', 'Performer', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank'),
			),
			'Electronics' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank'),
			),
			'ForeignBooks' => array(
				'params' => array('Author', 'BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'reviewrank', 'pricerank', 'inverse-pricerank', 'titlerank', '-titlerank'),
			),
			'Grocery' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Keywords', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank'),
			),
			'HealthPersonalCare' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank'),
			),
			'HomeGarden' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank'),
			),
			'HomeImprovement' => array( // !!
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('price', '-price', 'reviewrank', 'salesrank'),
			),
			'Jewelry' => array(
				'params' => array('Availability', 'BrowseNode', 'Keywords', 'MerchantId', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'relevancerank', 'reviewrank'),
			),
			'KindleStore' => array(
				'params' => array('Author', 'Availability', 'BrowseNode', 'Keywords', 'MaximumPrice', 'MerchantID', 'MinimumPrice', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', '-edition-sales-velocity', 'price', '-price', 'reviewrank', 'daterank', 'salesrank'),
			),
			'Kitchen' => array(
				'params' => array('Author', 'Availability', 'Brand', 'BrowseNode', 'Condition', 'Count', 'Format', 'ISPUPostalCode', 'ItemPage', 'Keywords', 'Magazines', 'Manufacturer', 'MerchantId', 'Performer', 'PostalCode', 'Sort', 'State', 'Title'),
				'sort_values' => array('price', '-price', 'relevancerank', 'salesrank'),
			),
			'Lighting' => array( // !!
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'relevancerank', 'price', '-price', 'reviewrank'),
			),
			'Magazines' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'titlerank', '-titlerank'),
			),
			'Marketplace' => array(
				'params' => array('Availability', 'BrowseNode', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank', '-launch-date'),
			),
			'MP3Downloads' => array(
				'params' => array('Availability', 'BrowseNode', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'relevancerank', 'reviewrank', 'price', '-price', 'artistalbumrank', '-artistalbumrank', 'albumrank', '-albumrank', 'runtime', '-runtime', '-releasedate', 'titlerank', '-titlerank'),
			),
			'Music' => array(
				'params' => array('Artist', 'Availability', 'BrowseNode', 'Count', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'MusicLabel', 'Performer', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'pubdate', '-pubdate', 'publicationdate', '-publicationdate', 'releasedate', '-releasedate', 'titlerank', '-titlerank'),
			),
			'MusicalInstruments' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Keywords', 'Sort', 'Title'),
				'sort_values' => array('reviewrank', 'salesrank', 'price', '-price', 'relevancerank'),
			),
			'MusicTracks' => array(
				'params' => array('Condition', 'ItemPage', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort'),
				'sort_values' => array('titlerank', '-titlerank'),
			),
			'OfficeProducts' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('price', '-price', 'relevancerank', 'reviewrank', 'salesrank'),
			),
			'OutdoorLiving' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank'),
			),
			'Outlet' => array(
				'params' => array('Keywords'),
				'sort_values' => array(),
			),
			'PCHardware' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('psrank', 'salesrank', 'price', '-price', 'titlerank', 'reviewrank'),
			),
			'Photo' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank'),
			),
			'Shoes' => array( // !!
				'params' => array('Brand', 'BrowseNode', 'Condition', 'Count', 'ItemPage', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Manufacturer', 'Power', 'Sort', 'Title'),
				'sort_values' => array('-launch-date', 'price', '-price', 'relevancerank', 'salesrank', 'reviewrank'),
			),
			'Software' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', '-date', 'titlerank', '-titlerank'),
			),
			'SoftwareVideoGames' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'reviewrank', 'price', 'inverse-pricerank', '-date', 'titlerank', '-titlerank'),
			),
			'SportingGoods' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank', 'release-date', '-release-date'),
			),
			'Tools' => array(
				'params' => array('Condition', 'ItemPage', 'Keywords', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-pricerank', 'titlerank', '-titlerank'),
			),
			'Toys' => array(
				'params' => array('BrowseNode', 'Condition', 'Count', 'ItemPage', 'Keywords', 'Sort', 'MerchantId', 'Title'),
				'sort_values' => array('pmrank', 'salesrank', 'price', '-price', '-date', 'titlerank'),
			),
			'VHS' => array(
				'params' => array('Actor', 'AudienceRating', 'Availability', 'BrowseNode', 'Count', 'Director', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'Performer', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank'),
			),
			'Video' => array(
				'params' => array('Actor', 'AudienceRating', 'Availability', 'BrowseNode', 'Count', 'Director', 'Format', 'ItemPage', 'Keywords', 'Magazines', 'Performer', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank'),
			),
			'VideoGames' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MerchantId', 'MinimumPrice', 'MPAARating', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', '-date', 'titlerank', '-titlerank'),
			),
			'Watches' => array(
				'params' => array('BrowseNode', 'Condition', 'ItemPage', 'Keywords', 'MerchantId', 'MinimumPrice', 'Sort', 'TextStream', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank'),
			),
		),
		
		'cn' => array(
			'All' => array(
				'params' => array('Keywords'),
				'sort_values' => array(),
			),
			'Apparel' => array(
				'params' => array('Availability', 'Author', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', '-launchdate'),
			),
			'Appliances' => array(
				'params' => array('Availability', 'Author', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', '-launchdate'),
			),
			'Automotive' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', '-launchdate'),
			),
			'Baby' => array(
				'params' => array('Availability', 'Author', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank'),
			),
			'Beauty' => array(
				'params' => array('Availability', 'Author', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank'),
			),
			'Books' => array(
				'params' => array('Author', 'Availability', 'BrowseNode', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Power', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'pricerank', 'inverse-pricerank', 'daterank', '-publication_date', 'titlerank', '-titlerank', 'price', '-price'),
			),
			'Electronics' => array(
				'params' => array('Author', 'Availability', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank', 'release-date', '-release-date'),
			),
			'Grocery' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank'),
			),
			'HealthPersonalCare' => array(
				'params' => array('Availability', 'Author', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank', 'release-date', '-release-date'),
			),
			'HomeGarden' => array( // !!
				'params' => array('Availability', 'Author', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank'),
			),
			'HomeImprovement' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank'),
			),
			'Jewelry' => array(
				'params' => array('Availability', 'BrowseNode', 'Keywords', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank'),
			),
			'Misc' => array(
				'params' => array('Availability', 'Author', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', '-launch-date'),
			),
			'Music' => array(
				'params' => array('Artist', 'Availability', 'BrowseNode', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'MusicLabel', 'ReleaseDate', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'titlerank', '-titlerank', 'orig-rel-date', '-orig-rel-date'),
			),
			'OfficeProducts' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'reviewrank', 'price', '-price'),
			),
			'Photo' => array(
				'params' => array('Availability', 'Author', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', '-launchdate'),
			),
			'Shoes' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('relevancerank', 'salesrank', 'price', '-price', 'reviewrank', '-launch-date'),
			),
			'Software' => array(
				'params' => array('Availability', 'Author', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank', 'releasedate', '-releasedate'),
			),
			'SportingGoods' => array(
				'params' => array('Availability', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank', 'releasedate', '-releasedate'),
			),
			'Toys' => array(
				'params' => array('Availability', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'reviewrank', 'titlerank', '-titlerank', 'releasedate', '-releasedate'),
			),
			'Video' => array(
				'params' => array('Actor', 'Availability', 'BrowseNode', 'Director', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'pricerank', '-pricerank', 'titlerank', '-titlerank', 'orig-rel-date', '-orig-rel-date'),
			),
			'VideoGames' => array(
				'params' => array('Availability', 'Author', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'ReleaseDate', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank', 'releasedate', '-releasedate'),
			),
			'Watches' => array(
				'params' => array('Availability', 'BrowseNode', 'Keywords', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'price', '-price', 'titlerank', '-titlerank'),
			),
		),
		
		'ca' => array(
			'All' => array(
				'params' => array('Keywords'),
				'sort_values' => array(),
			),
			'Blended' => array(
				'params' => array('Keywords'),
				'sort_values' => array(),
			),
			'Books' => array(
				'params' => array('Author', 'BrowseNode', 'Condition', 'Count', 'ItemPage', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Power', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'pricerank', 'inverse-pricerank', 'daterank', 'titlerank'),
			),
			'Classical' => array(
				'params' => array('Author', 'BrowseNode', 'Composer', 'Condition', 'Conductor', 'Count', 'ItemPage', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'MusicLabel', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'titlerank', 'orig-rel-date'),
			),
			'DVD' => array(
				'params' => array('Actor', 'AudienceRating', 'BrowseNode', 'Condition', 'Count', 'Director', 'ItemPage', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'titlerank'),
			),
			'Electronics' => array(
				'params' => array('BrowseNode', 'Condition', 'Count', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'ReleaseDate', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'relevancerank', 'price', '-price', 'titlerank', '-titlerank'),
			),
			'ForeignBooks' => array(
				'params' => array('BrowseNode', 'Condition', 'Count', 'ItemPage', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Power', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'pricerank', 'inverse-pricerank', 'daterank', 'titlerank'),
			),
			'Kitchen' => array(
				'params' => array('Availability', 'Brand', 'BrowseNode', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'relevancerank', 'price', '-price', 'reviewrank'),
			),
			'Music' => array(
				'params' => array('Artist', 'BrowseNode', 'Condition', 'Count', 'ItemPage', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'MusicLabel', 'Power', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'titlerank', 'orig-rel-date'),
			),
			'Software' => array(
				'params' => array('BrowseNode', 'Condition', 'Count', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'pricerank', 'inverse-pricerank', 'titlerank', '-daterank'),
			),
			'SoftwareVideoGames' => array(
				'params' => array('Author', 'BrowseNode', 'Condition', 'Count', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'pricerank', 'inverse-pricerank', 'titlerank', '-daterank'),
			),
			'VHS' => array(
				'params' => array('Actor', 'BrowseNode', 'Condition', 'Count', 'Director', 'ItemPage', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', '-titlerank'),
			),
			'Video' => array(
				'params' => array('Actor', 'AudienceRating', 'BrowseNode', 'Condition', 'Count', 'Director', 'ItemPage', 'Keywords', 'MaximumPrice', 'MinimumPrice', 'Publisher', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'titlerank', '-titlerank'),
			),
			'VideoGames' => array(
				'params' => array('Author', 'Brand', 'BrowseNode', 'Condition', 'Count', 'ItemPage', 'Keywords', 'Manufacturer', 'MaximumPrice', 'MinimumPrice', 'Sort', 'Title'),
				'sort_values' => array('salesrank', 'pricerank', 'inverse-pricerank', 'titlerank', '-titlerank'),
			),
		),
	);
	
	/**
	 * Human freandly titles of SearchIndex keys
	 * NOTE: only special cases are defined, names which are easily translate from camel case are not listed here
	 * @var array
	 */
	protected static $_search_index_titles = array(
		'ArtsAndCrafts' => 'Arts, Crafts & Sewing',
		'HealthPersonalCare' => 'Health & Personal Care',
		'HomeGarden' => 'Home & Garden',
		'Industrial' => 'Industrial & Scientific',
		'Kitchen' => 'Kitchen & Housewares',
		'Magazines' => 'Magazine Subscriptions',
		'MobileApps' => 'Mobile Applications',
		'OutdoorLiving' => 'Outdoors',
		'PCHardware' => 'Computers',
		'Photo' => 'Camera & Photo',
		'SoftwareVideoGames' => 'Software & Video Games',
		'SportingGoods' => 'Sports',
		'Tools' => 'Tools & Hardware',
		'Toys' => 'Toys & Games',
		'UnboxVideo' => 'Amazon Instant Video',
	);
	
	/**
	 * Explanaition of sort parameters
	 * @var array
	 */
	protected static $_sort_value_titles = array(
		'relevancerank' => 'Relevance',
		'salesrank' => 'Bestselling',
		'pricerank' => 'Price: low to high',
		'inverseprice' => 'Price: high to low',
		'-launch-date' => 'Newest arrivals',
		'sale-flag' => 'On sale',
		'pmrank' => 'Featured items',
		'price' => 'Price: low to high',
		'-price' => 'Price: high to low',
		'reviewrank' => 'Average customer review: high to low',
		'titlerank' => 'Alphabetical: A to Z',
		'-titlerank' => 'Alphabetical: Z to A',
		'psrank' => 'Bestseller (projected sales)',
		'inverse-pricerank' => 'Price: high to low',
		'daterank' => 'Publication date: newer to older',
		'orig-rel-date' => 'Release date: newer to older',
		'-orig-rel-date' => 'Release date: older to newer',
		'releasedate' => 'Release date: newer to older',
		'-releasedate' => 'Release date: older to newer',
		'songtitlerank' => 'Most popular',
		'uploaddaterank' => 'Date added',
		'launch-date' => 'Newest launches first',
		'-video-release-date' => 'Release date: newer to older',
		'-edition-sales-velocity' => 'Release date: newer to older',
		'subslot-salesrank' => 'Bestselling',
		'artistrank' => 'Artist name: A to Z',
		'release-date' => 'Release date: newer to older',
		'+pmrank' => 'Featured items',
		'-age-min' => 'Recommended age: high to low',
		'pubdate' => 'Publication date: older to newer',
		'-mfg-age-min' => 'Recommended age: high to low',
		'mfg-age-min' => 'Recommended age: low to high',
		'-pricerank' => 'Price: high to low',
		'-release-date' => 'Release date: newer to older',
		'artistalbumrank' => 'Artist album rank: high to low',
		'-artistalbumrank' => 'Artist album rank: low to high',
		'albumrank' => 'Album rank: high to low',
		'-albumrank' => 'Album rank: low to high',
		'runtime' => 'Track length: high to low',
		'-runtime' => '	Track length: low to high',
		'price-new-bin' => 'Price: low to high',
		'-price-new-bin' => 'Price: high to low',
		'reviewrank_authority' => 'Review rank: high to low',
		'-releank' => 'Review rank: low to high',
		'-pubdate' => 'Publish date: oldest to recent',
		'-daterank' => 'Pub Date: Old to New',
		'amzrank' => 'Alphabetical: A to Z',
		'availability' => 'Most to least available',
		'-date' => 'Release Date: Old to New',
		'date' => 'Release Date: new to old',
		'-publicationdate' => 'Publication date: oldest to most recent',
		'publication_date' => 'Publication date: most recent to oldest',
		'-publication_date' => 'Publication date: oldest to most recent',
		'publicationdate' => 'Publication date: most recent to oldest',
		'-launchdate' => 'Latest arrivals',
	);
	
	/**
	 * Return array of locales defined
	 */
	public static function all()
	{
		return array_keys(self::$_titles);
	}
	
	/**
	 * Return param found in array for a locale 
	 * @param array $params
	 * @param string $locale
	 */
	protected static function _param($params, $locale)
	{
		if ( ! isset($params[$locale])) {
			throw new AmazonAAWS_Locale_Exception("Locale `$locale` is not defined");
		}
		return $params[$locale];
	}
	
	/**
	 * Return title for a specified locale
	 * @param string $locale
	 */
	public static function title($locale = AmazonAAWS_Locale::US)
	{
		return self::_param(self::$_titles, $locale);
	}
	
	/**
	 * Return human freindly title for a SearchIndex
	 * @param string $search_index
	 * @return string
	 */
	public static function search_index_title($search_index)
	{
		if (isset(self::$_search_index_titles[$search_index])) {
			return self::$_search_index_titles[$search_index];
		}
		// fallback rule: translate camle name
		return preg_replace('%(?<=[a-z0-9])\B(?=[A-Z])%', ' ', $search_index);
	}
	
	/**
	 * Return human friendly title for SortValue
	 * @param string $sort_value
	 * @return string
	 */
	public static function sort_value_title($sort_value)
	{
		if (isset(self::$_sort_value_titles[$sort_value])) {
			return self::$_sort_value_titles[$sort_value];
		}
		// fallback rule: return value itself
		return $sort_value;
	}
	
	/**
	 * Return list of available search indexes for a locale
	 * @param array[optional] $locale
	 * @return array
	 */
	public static function search_indexes($locale = AmazonAAWS_Locale::US)
	{
		return array_keys(self::_param(self::$_search_indexes, $locale));
	}
	
	/**
	 * Return list of available sort values for a search index and locale combination
	 * @param string $search_index
	 * @param string[optional] $locale
	 * @return array
	 */
	public static function search_sort_values($search_index, $locale = AmazonAAWS_Locale::US)
	{
		if ( ! isset(self::$_search_indexes[$locale][$search_index])) {
			throw new AmazonAAWS_Locale_Exception("Search index `$search_index` is not defined for `$locale` locale");
		}
		
		return self::$_search_indexes[$locale][$search_index]['sort_values'];
	}
	
	/**
	 * Return list of available parameters for a search index and locale combination
	 * @param string $search_index
	 * @param string[optional] $locale
	 * @return array
	 */
	public static function search_params($search_index, $locale = AmazonAAWS_Locale::US)
	{
		if ( ! isset(self::$_search_indexes[$locale][$search_index])) {
			throw new AmazonAAWS_Locale_Exception("Search index `$search_index` is not defined for `$locale` locale");
		}
		
		return self::$_search_indexes[$locale][$search_index]['params'];
	}
	
	/**
	 * Return endpoint hostname for specified locale
	 * @param string[optional] $locale
	 * @return string
	 */
	public static function endpoint($locale = AmazonAAWS_Locale::US)
	{
		return self::_param(self::$_endpoints, $locale);
	}
	
	/**
	 * Return currency symbol for specified locale
	 * @param string[optional] $locale
	 * @return string
	 */
	public static function currency_symbol($locale = AmazonAAWS_Locale::US)
	{
		return self::_param(self::$_currency_symbols, $locale);
	}
	
	/**
	 * Return currency format for specified locale as array(<decimal precision>, <decimal delimiter>, <thouthand delimiter>)
	 * @param string[optional] $locale
	 * @return array
	 */
	public static function currency_format($number, $locale = AmazonAAWS_Locale::US)
	{
		$param_arr = self::_param(self::$_currency_formats, $locale);
		array_unshift($param_arr, $number);
		return call_user_func_array('number_format', $param_arr);
	}
	
	/**
	 * Return amazon website root domain for specified locale
	 * @param string[optional] $locale
	 * @return string
	 */
	public static function root_domain($locale = AmazonAAWS_Locale::US)
	{
		return self::_param(self::$_root_domains, $locale);
	}
	
	/**
	 * Return amazon website domain for specified locale
	 * @param string[optional] $locale
	 * @return string
	 */
	public static function domain($locale = AmazonAAWS_Locale::US)
	{
		return 'www.amazon.' . self::_param(self::$_root_domains, $locale);
	}
	
	/**
	 * Convert full price representation (may even contain currency symbol) into float number
	 * @param string $price
	 * @param string[optional] $symbol
	 * @param array[optional] $format
	 * @return float|NULL
	 */
	public static function price_to_float($price, & $symbol = NULL, & $format = NULL)
	{
		$price = trim($price);
		if (preg_match('%^[^\d]+%', $price, $mtch)) {
			$symbol = $mtch[0];
			$price = preg_replace('%^[^\d]+%', '', $price); // remove currency symbol if present
		}
		if (preg_match('%^\d{1,3}(,\d{3})*(\.\d{1,2})?$%', $price)) { // US format
			$price = str_replace(',', '', $price);
			$format = array('.', ',');
			$price = floatval($price);
		} elseif (preg_match('%^\d{1,3}(\.\d{3})*(,\d{1,2})?$%', $price)) { // EU format
			$price = str_replace('.', '', $price);
			$price = str_replace(',', '.', $price);
			$price = floatval($price);
			$format = array(',', '.');
		} else { // not recognized
			$price = NULL;
			$symbol = NULL;
			$format = array();
		}
		
		return $price;
	}
	
	/**
	 * Scrape format for avarage rating and total reviews for a specified locale
	 * @param string $locale
	 * @return array
	 */
	public static function scrape_format($locale = AmazonAAWS_Locale::US)
	{
		return array(self::_param(self::$_rating_formats, $locale), self::_param(self::$_reviews_formats, $locale));
	}
}
